<?php namespace App\Modules\Backend\Auth\Controllers;

use Auth, Input, Redirect, View, Alert;

class AuthController extends \BaseController {

	/**
	 * Muestra el formulario para iniciar sesión.
	 *
	 * @return View
	 */
	public function getLogin()
	{
		if (!Auth::check())
			return View::make('auth::login');
		else
			return Redirect::to('admin/dashboard');
	}

	/**
	 * Valida los datos del usuario.
	 */
	public function postLogin()
	{
		$userdata = array(
            'username' => Input::get('username'),
            'password'=> Input::get('password')
        );
		
        if(Auth::attempt($userdata, Input::get('remember-me', 0)) )
        {
        	return Redirect::to('admin');
        }
        // En caso de que la autenticación haya fallado manda un mensaje al formulario de login.
        Alert::message(trans('auth::message.error_authentication'), 'danger');
        return Redirect::to('admin/login')
				    ->withInput();
	}

	/**
	 * Muestra el formulario de login mostrando un mensaje de que cerro sesión.
	 */
	public function getLogout()
	{
		// Verificamos que el usuario no este autenticado
		if (!Auth::check())
		{
		    // Si no esta autenticado lo mandamos a login sin ningún mensaje.
		    return Redirect::to('admin/login');
		}

		Auth::logout();
		Alert::message(trans('auth::message.success_logout'), 'warning');
		return Redirect::to('admin/login');
	}
}